@@ -2,22 +2,23 @@ import dataclasses
 from string import ascii_letters
 from types import NoneType
 
-from sqlalchemy.orm import Mapped
-from sqlalchemy.schema import Column
-from sqlalchemy.sql import sqltypes
 from pytech.sqlalchemy_tools.models import BaseSqlModel
+from sqlalchemy.orm import Mapped
+from sqlalchemy.schema import Column, UniqueConstraint
+from sqlalchemy.sql import sqltypes
 
 __all__ = [
     "build_sqlalchemy_model"
 ]
 
 
-def build_sqlalchemy_model(
+def build_sqlalchemy_model( # noqa: PLR0912, PLR0913
         from_dataclass: type,
         table_name: str,
         model_name: str,
-        additional_fields: dict = None,
-        pk_fields: list = None,
+        additional_fields: dict | None = None,
+        pk_fields: list | None = None,
+        unique_fields: list | None = None,
         extensible_model: bool = False
 ) -> BaseSqlModel:
     """
@@ -37,6 +38,7 @@ def build_sqlalchemy_model(
     :param model_name: the name the Model class will take.
     :param additional_fields: fields to add to the model.
     :param pk_fields: the fields to use as primary key.
+    :param unique_fields: the fields for which to set a unique constraint.
     :param extensible_model: specifies if the model can be extended default False).
     :return: the BaseSqlModel created from the dataclass.
     """
@@ -58,13 +60,16 @@ def build_sqlalchemy_model(
     if not isinstance(pk_fields, list | NoneType):
         raise TypeError("'pk_fields' must be a list.")
 
+    if not isinstance(unique_fields, list | NoneType):
+        raise TypeError("'unique_fields' must be a list.")
+
     # All dataclass annotations must be Mappable SQLAlchemy types.
     invalid_keys = [
         key
         for key, val in from_dataclass.__annotations__.items()
         if val not in sqltypes._type_map
     ]
-    if len(invalid_keys):
+    if invalid_keys:
         raise ValueError(
             f"'from_dataclass' has invalid annotations: {', '.join(invalid_keys)}"
         )
@@ -85,10 +90,10 @@ def build_sqlalchemy_model(
     }
 
     if additional_fields:
-        # If additional_fields are defined we check they are well defined
+        # If additional_fields are defined we check they are well-defined
         if not all([
             set(field_name).issubset(f"_{ascii_letters}")
-            for field_name in additional_fields.keys()
+            for field_name in additional_fields
         ]):
             raise ValueError("'additional_fields' contains invalid characters.")
 
@@ -111,12 +116,19 @@ def build_sqlalchemy_model(
             },
         }
 
+    table_args = []
+    if unique_fields:
+        if not set(unique_fields).issubset(_dataclass_fields.keys()):
+            raise ValueError("'unique_fields' must be a list of valid keys.")
+        table_args.append(UniqueConstraint(*unique_fields))
+
     if extensible_model:
-        model_attrs |= {
-            "__table_args__": {
-                "extend_existing": True
-            }
-        }
+        table_args.append({"extend_existing": True})
+
+    model_attrs |= {
+        "__table_args__": tuple(table_args)
+    }
+
 
     return type(
         model_name,
