@@ -1,16 +1,16 @@
 import dataclasses
 
+from pytech.sqlalchemy_tools.models import BaseSqlModel
 from sqlalchemy.orm import Session
 from sqlalchemy.sql import select
 from sqlalchemy.sql._typing import _ColumnExpressionArgument
-from pytech.sqlalchemy_tools.models import BaseSqlModel
 
 __all__ = ["retrieve_all_data"]
 
 
 def retrieve_all_data(
         session: Session,
-        model: type(BaseSqlModel),
+        model: type[BaseSqlModel],
         where_clause: _ColumnExpressionArgument[bool] = None
 ) -> list:
     """
